==> org.eclipse.scout.sdk.source_3.9.1.20130910-1025.jar: org/eclipse/scout/sdk/operation/template/sequencebox/DateFromToTemplate.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.sdk.operation.template.sequencebox;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jdt.core.IType;
import org.eclipse.scout.nls.sdk.model.INlsEntry;
import org.eclipse.scout.nls.sdk.model.workspace.project.INlsProject;
import org.eclipse.scout.sdk.extensions.runtime.classes.RuntimeClasses;
import org.eclipse.scout.sdk.operation.form.field.FormFieldNewOperation;
import org.eclipse.scout.sdk.operation.method.NlsTextMethodUpdateOperation;
import org.eclipse.scout.sdk.operation.template.IContentTemplate;
import org.eclipse.scout.sdk.util.SdkProperties;
import org.eclipse.scout.sdk.util.typecache.IWorkingCopyManager;
import org.eclipse.scout.sdk.workspace.type.ScoutTypeUtility;

public class DateFromToTemplate implements IContentTemplate {
  private IType m_fromType;
  private IType m_toType;

  @Override
  public String getName() {
    return "Date FROM-TO";
  }

  @Override
  public void apply(IType type, IWorkingCopyManager manager, IProgressMonitor monitor) throws CoreException {
    monitor.beginTask("apply " + getName() + " template.", IProgressMonitor.UNKNOWN);

    String superTypeSignature = RuntimeClasses.getSuperTypeSignature(RuntimeClasses.IDateField, type.getJavaProject());

    String parentName = type.getElementName();
    int lastBoxIndex = parentName.lastIndexOf(SdkProperties.SUFFIX_BOX);
    if (lastBoxIndex > 0) {
      parentName = parentName.substring(0, lastBoxIndex);
    }
    FormFieldNewOperation fromOp = new FormFieldNewOperation(type, false);
    fromOp.setTypeName(parentName + SdkProperties.SUFFIX_FROM);
    fromOp.setSiblingField(null);
    fromOp.setSuperTypeSignature(superTypeSignature);
    fromOp.validate();
    fromOp.run(monitor, manager);
    m_fromType = fromOp.getCreatedFormField();

    FormFieldNewOperation toOp = new FormFieldNewOperation(type, false);
    toOp.setTypeName(parentName + SdkProperties.SUFFIX_TO);
    toOp.setSiblingField(null);
    toOp.setSuperTypeSignature(superTypeSignature);
    toOp.validate();
    toOp.run(monitor, manager);
    m_toType = toOp.getCreatedFormField();

    INlsProject nlsProject = ScoutTypeUtility.findNlsProject(type);
    if (nlsProject != null) {
      INlsEntry fromEntry = nlsProject.getEntry("from");
      if (fromEntry != null) {
        NlsTextMethodUpdateOperation fromNlsOp = new NlsTextMethodUpdateOperation(getFromType(), "getConfiguredLabel");
        fromNlsOp.setNlsEntry(fromEntry);
        fromNlsOp.validate();
        fromNlsOp.run(monitor, manager);
      }
      INlsEntry toEntry = nlsProject.getEntry("to");
      if (toEntry != null) {
        NlsTextMethodUpdateOperation toNlsOp = new NlsTextMethodUpdateOperation(getToType(), "getConfiguredLabel");
        toNlsOp.setNlsEntry(toEntry);
        toNlsOp.validate();
        toNlsOp.run(monitor, manager);
      }

    }
    monitor.done();
  }

  public IType getFromType() {
    return m_fromType;
  }

  public IType getToType() {
    return m_toType;
  }
}

==> org.eclipse.scout.sdk.source_5.0.100.20150806-0740.jar: org/eclipse/scout/sdk/operation/template/sequencebox/DateFromToTemplate.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.sdk.operation.template.sequencebox;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jdt.core.IType;
import org.eclipse.scout.sdk.extensions.runtime.classes.IRuntimeClasses;
import org.eclipse.scout.sdk.extensions.runtime.classes.RuntimeClasses;
import org.eclipse.scout.sdk.sourcebuilder.type.ITypeSourceBuilder;
import org.eclipse.scout.sdk.util.typecache.IWorkingCopyManager;

public class DateFromToTemplate extends AbstractFormFieldTemplate {

  @Override
  public String getName() {
    return "Date FROM-TO";
  }

  @Override
  public void apply(ITypeSourceBuilder sourceBuilder, IType declaringType, IProgressMonitor monitor, IWorkingCopyManager manager) throws CoreException {
    apply(sourceBuilder, declaringType, RuntimeClasses.getSuperTypeSignature(IRuntimeClasses.IDateField, declaringType.getJavaProject()), monitor, manager);
  }

}
